TimeAtlas
=========

![PyPI version](https://badge.fury.io/py/timeatlas.svg)
![PyPI Downloads](https://img.shields.io/pypi/dm/timeatlas)
![GitHub - License](https://img.shields.io/github/license/timeatlas-dev/timeatlas)

**timeatlas** is an open source library for sensor data analysis and more. 
It aims at providing a comprehensive API for time series analysis,
prediction, as well as anomaly detections.
